"""Top-level package for SunTzu."""
from .cleaning import Cleaning #noqa
from .file import File #noqa
from .file import read_file #noqa
from .metadata import netCDF_Metadata #noqa
from .statistics import Statistics #noqa
from .metadata import ParquetMetadata #noqa
__author__ = """Igor Coimbra Carvalheira"""
__email__ = 'igorccarvalheira111@gmail.com'
__version__ = '0.1.0'
__all__ = ['test']
